@@ -3,6 +3,7 @@
 
 
 import re
+import sys
 
 
 
@@ -71,7 +72,7 @@ def warn_helper(msg):
     msg -- warning message to display
     """
 
-    print("warning: " + msg, file=sys.stderr)
+    print("warning:", msg, file=sys.stderr)
 
 
     # helper functions return a string to be included in the template;
@@ -309,4 +310,4 @@ def to_dict_helper(s):
     return d
 
 
-helpers["to_dict"] = to_dict_helper
\ No newline at end of file
+helpers["to_dict"] = to_dict_helper
